GUI elements (gui)

# Orange Canvas Core 0.0.8 documentation

## GUI elements (gui)

# GUI elements (`gui`)

## GUI toolkit

A GUI toolkit with widgets used by other parts of Orange Canvas.

Extends basic Qt classes with extra functionality.

- Collapsible Dock Widget (`dock`)
- Drop Shadow Frame (`dropshadow`)
- Frameless Window Widget (`framelesswindow`)
- Line Edit Widget (`lineedit`)
- Quick Help (`quickhelp`)
- Splash Screen (`splashscreen`)
- Stacked Widget (`stackedwidget`)
- Tool Bar (`toolbar`)
- Tool Box Widget (`toolbox`)
- Tool Grid Widget (`toolgrid`)
- Tool Tree Widget (`tooltree`)